/* $NetBSD: lsym_switch.c,v 1.3 2022/04/24 09:04:12 rillig Exp $ */

/*
 * Tests for the token lsym_switch, which represents the keyword 'switch' that
 * starts a 'switch' statement.
 *
 * See also:
 *	C11 6.8.4		"Selection statements"
 *	C11 6.8.4.2		"The 'switch' statement"
 */

//indent input
// TODO: add input
//indent end

//indent run-equals-input
