/* $NetBSD: psym_lbrace.c,v 1.3 2022/04/24 09:04:12 rillig Exp $ */

/*
 * Tests for the parser symbol psym_lbrace, which represents a '{'.
 *
 * TODO: could this be a '{' from an initializer as well?
 *
 * See also:
 *	psym_rbrace.c
 */

//indent input
// TODO: add input
//indent end

//indent run-equals-input
